@@ -17,34 +17,48 @@
 
 import os
 import sys
+import six
 import datetime
 
 from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
 from django.template import Context
 
+
 class Command(BaseCommand):
-    
-    help = 'Build django project with our settting and files.'
-    
+    help = 'Build django project with our setting and files.'
+
     def add_arguments(self, parser):
         parser.add_argument('name', type=str, help="Project name")
-        parser.add_argument('path', type=str, help="Project path")
-    
+        parser.add_argument('path', type=str, nargs='?', help="Project path")
+
     def handle(self, *args, **options):
         path = options['path']
         name = options['name']
 
-        path = os.path.join(path, options['name'])
-        os.mkdir(path)
-
-        import django
-        if not (django.VERSION[0] == 1 and django.VERSION[1] == 8):
-            raise CommandError("Only support django 1.8.x")
+        if not path:
+            path = os.path.join(os.getcwd(), options['name'])
+        else:
+            path = os.path.join(path, options['name'])
 
         # FIXME: 判斷 Manage.py
-        os.system(
-            "%s manage.py startproject %s %s" % (sys.executable,  name, path))
+        if os.path.abspath(path) == os.path.abspath(
+                os.path.join(os.getcwd(), options['name'])):
+            os.system(
+                "%s manage.py startproject %s" % (
+                    sys.executable, name))
+        else:
+            if not os.path.exists(path):
+                os.mkdir(path)
+
+            os.system(
+                "%s manage.py startproject %s \"%s\"" % (
+                    sys.executable, name, path))
+
+        import django
+
+        if not (django.VERSION[0] == 1 and django.VERSION[1] == 8):
+            raise CommandError("Only support django 1.8.x")
 
         settingPath = os.path.join(path, name, 'settings.py')
         urlPath = os.path.join(path, name, 'urls.py')
@@ -52,20 +66,20 @@ class Command(BaseCommand):
         def renderFile(template, path, fileName, linux=False):
             temp = get_template(template)
             content = temp.render()
-            
+
             if linux:
                 with open(os.path.join(path, fileName), 'wb') as f:
-                    f.write(content.replace('\r\n', '\n'))
+                    f.write(six.b(content.replace('\r\n', '\n')))
             else:
                 with open(os.path.join(path, fileName), 'w') as f:
                     f.write(content)
 
         # file -----------------------------------------------------------------
-        renderFile('scaffold/Activate.bat', path, 'Activate.bat')      
+        renderFile('scaffold/Activate.bat', path, 'Activate.bat')
         renderFile('scaffold/Configure.bat', path, 'Configure.bat')
-        renderFile('scaffold/Configure.sh', path, 'Configure.sh', linux=True)   
-        renderFile('scaffold/README.txt', path, 'README.txt')    
-        renderFile('scaffold/REQUIREMENTS.txt', path, 'REQUIREMENTS.txt') 
+        renderFile('scaffold/Configure.sh', path, 'Configure.sh', linux=True)
+        renderFile('scaffold/README.txt', path, 'README.txt')
+        renderFile('scaffold/REQUIREMENTS.txt', path, 'REQUIREMENTS.txt')
 
         # Settings.py ----------------------------------------------------------
         with open(settingPath, 'r') as setting:
@@ -73,7 +87,7 @@ class Command(BaseCommand):
 
         # Header
         context = Context({
-            "year": datetime.date.today().year, 
+            "year": datetime.date.today().year,
         })
         temp = get_template('scaffold/HeaderTemplate.py')
         header = temp.render(context)
@@ -81,7 +95,7 @@ class Command(BaseCommand):
 
         # debug & mode
         context = Context({
-            "name": name.lower(), 
+            "name": name.lower(),
         })
         temp = get_template('scaffold/DebugTemplate.py')
         debug = temp.render(context)
@@ -116,7 +130,7 @@ class Command(BaseCommand):
         content = content.strip() + '\n' + footer
 
         with open(settingPath, 'wb') as setting:
-            setting.write(content.replace('\r\n', '\n'))
+            setting.write(six.b(content.replace('\r\n', '\n')))
 
         # Urls.py --------------------------------------------------------------
         with open(urlPath, 'r') as url:
@@ -129,6 +143,5 @@ class Command(BaseCommand):
         with open(urlPath, 'w') as url:
             url.write(content)
 
-             
 
-        
+
